/**
 */
package de.mdelab.mlsdm;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import de.mdelab.mlexpressions.MLExpression;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Activity Edge</b></em>'. <!-- end-user-doc -->
 * 
 * <!-- begin-model-doc --> Superclass of all edges that can be contained in an
 * Activity. Edges can have a guard. However, depending on the source node only
 * certain kinds of guards are valid. For the guard BOOLEAN, a guardExpression
 * has to be provided. <!-- end-model-doc -->
 * 
 * <p>
 * The following features are supported:
 * <ul>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getSource <em>Source</em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getTarget <em>Target</em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getActivityNodeContainer <em>Activity
 * Node Container</em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getGuardType <em>Guard Type</em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getGuardExpression <em>Guard
 * Expression</em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getAcquireEdges <em>Acquire Edges
 * </em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getReleaseEdges <em>Release Edges
 * </em>}</li>
 * <li>{@link de.mdelab.mlsdm.ActivityEdge#getAssertionExpressions <em>Assertion
 * Expressions</em>}</li>
 * </ul>
 * </p>
 * 
 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge()
 * @model
 * @generated
 */
public interface ActivityEdge extends MLElementWithUUID, MLAnnotatedElement
{
	/**
	 * Returns the value of the '<em><b>Source</b></em>' reference. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ActivityNode#getOutgoingEdges
	 * <em>Outgoing Edges</em>}'. <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Source</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Source</em>' reference.
	 * @see #setSource(ActivityNode)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_Source()
	 * @see de.mdelab.mlsdm.ActivityNode#getOutgoingEdges
	 * @model opposite="outgoingEdges" resolveProxies="false" required="true"
	 * @generated
	 */
	ActivityNode getSource();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getSource
	 * <em>Source</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Source</em>' reference.
	 * @see #getSource()
	 * @generated
	 */
	void setSource(ActivityNode value);

	/**
	 * Returns the value of the '<em><b>Target</b></em>' reference. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ActivityNode#getIncomingEdges
	 * <em>Incoming Edges</em>}'. <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Target</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Target</em>' reference.
	 * @see #setTarget(ActivityNode)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_Target()
	 * @see de.mdelab.mlsdm.ActivityNode#getIncomingEdges
	 * @model opposite="incomingEdges" resolveProxies="false" required="true"
	 * @generated
	 */
	ActivityNode getTarget();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getTarget
	 * <em>Target</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Target</em>' reference.
	 * @see #getTarget()
	 * @generated
	 */
	void setTarget(ActivityNode value);

	/**
	 * Returns the value of the '<em><b>Activity Node Container</b></em>'
	 * container reference. It is bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ActivityNodeContainer#getEdges <em>Edges</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Activity Node Container</em>' container
	 * reference isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Activity Node Container</em>' container
	 *         reference.
	 * @see #setActivityNodeContainer(ActivityNodeContainer)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_ActivityNodeContainer()
	 * @see de.mdelab.mlsdm.ActivityNodeContainer#getEdges
	 * @model opposite="edges" resolveProxies="false" required="true"
	 *        transient="false"
	 * @generated
	 */
	ActivityNodeContainer getActivityNodeContainer();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlsdm.ActivityEdge#getActivityNodeContainer
	 * <em>Activity Node Container</em>}' container reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Activity Node Container</em>'
	 *            container reference.
	 * @see #getActivityNodeContainer()
	 * @generated
	 */
	void setActivityNodeContainer(ActivityNodeContainer value);

	/**
	 * Returns the value of the '<em><b>Guard Type</b></em>' attribute. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlsdm.ActivityEdgeGuardEnum}. <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Guard Type</em>' attribute isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Guard Type</em>' attribute.
	 * @see de.mdelab.mlsdm.ActivityEdgeGuardEnum
	 * @see #setGuardType(ActivityEdgeGuardEnum)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_GuardType()
	 * @model required="true"
	 * @generated
	 */
	ActivityEdgeGuardEnum getGuardType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getGuardType
	 * <em>Guard Type</em>}' attribute. <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Guard Type</em>' attribute.
	 * @see de.mdelab.mlsdm.ActivityEdgeGuardEnum
	 * @see #getGuardType()
	 * @generated
	 */
	void setGuardType(ActivityEdgeGuardEnum value);

	/**
	 * Returns the value of the '<em><b>Guard Expression</b></em>' containment
	 * reference. <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Guard Expression</em>' containment reference
	 * isn't clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Guard Expression</em>' containment
	 *         reference.
	 * @see #setGuardExpression(MLExpression)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_GuardExpression()
	 * @model containment="true"
	 * @generated
	 */
	MLExpression getGuardExpression();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlsdm.ActivityEdge#getGuardExpression
	 * <em>Guard Expression</em>}' containment reference. <!-- begin-user-doc
	 * --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Guard Expression</em>' containment
	 *            reference.
	 * @see #getGuardExpression()
	 * @generated
	 */
	void setGuardExpression(MLExpression value);

	/**
	 * Returns the value of the '<em><b>Acquire Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.AcquireEdge}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.AcquireEdge#getActivityEdge
	 * <em>Activity Edge</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc --> Before this edge can be traversed, tokens have
	 * to be acquired from the semaphores connected by AcquireEdges. <!--
	 * end-model-doc -->
	 * 
	 * @return the value of the '<em>Acquire Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_AcquireEdges()
	 * @see de.mdelab.mlsdm.AcquireEdge#getActivityEdge
	 * @model opposite="activityEdge" resolveProxies="false" ordered="false"
	 * @generated
	 */
	EList<AcquireEdge> getAcquireEdges();

	/**
	 * Returns the value of the '<em><b>Release Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.ReleaseEdge}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ReleaseEdge#getActivityEdge
	 * <em>Activity Edge</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc --> When this edge is traversed, tokens are released
	 * to the semaphores connected by ReleaseEdges. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Release Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_ReleaseEdges()
	 * @see de.mdelab.mlsdm.ReleaseEdge#getActivityEdge
	 * @model opposite="activityEdge" resolveProxies="false" ordered="false"
	 * @generated
	 */
	EList<ReleaseEdge> getReleaseEdges();

	/**
	 * Returns the value of the '<em><b>Assertion Expressions</b></em>'
	 * containment reference list. The list contents are of type
	 * {@link de.mdelab.mlexpressions.MLExpression}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> A set of assertion
	 * expressions that are evaluated when the edge is traversed (and the
	 * interpreter is configured to evaluate assertions). If an expression is
	 * evaluated to false, an exception is thrown. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Assertion Expressions</em>' containment
	 *         reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_AssertionExpressions()
	 * @model containment="true" ordered="false"
	 * @generated
	 */
	EList<MLExpression> getAssertionExpressions();

} // ActivityEdge
