/**
 */
package de.mdelab.mlsdm;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import de.mdelab.mlcore.MLNamedElement;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Semaphore</b></em>'. <!-- end-user-doc -->
 * 
 * <!-- begin-model-doc --> A semaphore is used to control access to shared
 * resources by concurrent threads. AcquireEdges take tokens from a Semaphore
 * when the ActivityEdge of the AcquireEdge is executed. A ReleaseEdge does the
 * opposite, i.e., when its ActivityEdge is executed, tokens are put back to the
 * semaphore. <!-- end-model-doc -->
 * 
 * <p>
 * The following features are supported:
 * <ul>
 * <li>{@link de.mdelab.mlsdm.Semaphore#getActivityNodeContainer <em>Activity
 * Node Container</em>}</li>
 * <li>{@link de.mdelab.mlsdm.Semaphore#getTokenCount <em>Token Count</em>}</li>
 * <li>{@link de.mdelab.mlsdm.Semaphore#getAcquireEdges <em>Acquire Edges</em>}</li>
 * <li>{@link de.mdelab.mlsdm.Semaphore#getReleaseEdges <em>Release Edges</em>}</li>
 * </ul>
 * </p>
 * 
 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore()
 * @model
 * @generated
 */
public interface Semaphore extends MLElementWithUUID, MLAnnotatedElement, MLNamedElement
{
	/**
	 * Returns the value of the '<em><b>Activity Node Container</b></em>'
	 * container reference. It is bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ActivityNodeContainer#getSemaphores
	 * <em>Semaphores</em>}'. <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Activity Node Container</em>' container
	 * reference isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Activity Node Container</em>' container
	 *         reference.
	 * @see #setActivityNodeContainer(ActivityNodeContainer)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_ActivityNodeContainer()
	 * @see de.mdelab.mlsdm.ActivityNodeContainer#getSemaphores
	 * @model opposite="semaphores" resolveProxies="false" required="true"
	 *        transient="false"
	 * @generated
	 */
	ActivityNodeContainer getActivityNodeContainer();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlsdm.Semaphore#getActivityNodeContainer
	 * <em>Activity Node Container</em>}' container reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Activity Node Container</em>'
	 *            container reference.
	 * @see #getActivityNodeContainer()
	 * @generated
	 */
	void setActivityNodeContainer(ActivityNodeContainer value);

	/**
	 * Returns the value of the '<em><b>Token Count</b></em>' attribute. The
	 * default value is <code>"1"</code>. <!-- begin-user-doc --> <!--
	 * end-user-doc --> <!-- begin-model-doc --> The number of tokens initially
	 * contained in this semaphore. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Token Count</em>' attribute.
	 * @see #setTokenCount(int)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_TokenCount()
	 * @model default="1" required="true"
	 * @generated
	 */
	int getTokenCount();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.Semaphore#getTokenCount
	 * <em>Token Count</em>}' attribute. <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Token Count</em>' attribute.
	 * @see #getTokenCount()
	 * @generated
	 */
	void setTokenCount(int value);

	/**
	 * Returns the value of the '<em><b>Acquire Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.AcquireEdge}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.AcquireEdge#getSemaphore <em>Semaphore</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Acquire Edges</em>' reference list isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Acquire Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_AcquireEdges()
	 * @see de.mdelab.mlsdm.AcquireEdge#getSemaphore
	 * @model opposite="semaphore" resolveProxies="false" required="true"
	 *        ordered="false"
	 * @generated
	 */
	EList<AcquireEdge> getAcquireEdges();

	/**
	 * Returns the value of the '<em><b>Release Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.ReleaseEdge}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlsdm.ReleaseEdge#getSemaphore <em>Semaphore</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Release Edges</em>' reference list isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * 
	 * @return the value of the '<em>Release Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_ReleaseEdges()
	 * @see de.mdelab.mlsdm.ReleaseEdge#getSemaphore
	 * @model opposite="semaphore" resolveProxies="false" required="true"
	 *        ordered="false"
	 * @generated
	 */
	EList<ReleaseEdge> getReleaseEdges();

} // Semaphore
